@@ -42,8 +42,10 @@
 #include "ass_rasterizer.h"
 
 #define GLYPH_CACHE_MAX 10000
-#define BITMAP_CACHE_MAX_SIZE 128 * 1048576
-#define COMPOSITE_CACHE_MAX_SIZE 64 * 1048576
+#define MEGABYTE (1024 * 1024)
+#define BITMAP_CACHE_MAX_SIZE (128 * MEGABYTE)
+#define COMPOSITE_CACHE_RATIO 2
+#define COMPOSITE_CACHE_MAX_SIZE (BITMAP_CACHE_MAX_SIZE / COMPOSITE_CACHE_RATIO)
 
 #define PARSED_FADE (1<<0)
 #define PARSED_A    (1<<1)
@@ -211,7 +213,6 @@ typedef struct {
     ASS_Event *event;
     ASS_Style *style;
     int parsed_tags;
-    int has_clips;              // clips that conflict with cache change detection
 
     ASS_Font *font;
     double font_size;
@@ -220,6 +221,7 @@ typedef struct {
     FT_Stroker stroker;
     int stroker_radius;         // last stroker radius, for caching stroker objects
     int alignment;              // alignment overrides go here; if zero, style value will be used
+    int justify;                // justify instructions
     double frx, fry, frz;
     double fax, fay;            // text shearing
     enum {
